@@ -1,5 +1,5 @@
 import gzip
-import md5
+import hashlib
 import os
 import re
 import StringIO
@@ -162,12 +162,22 @@ class AutomaticRepository(AbstractRepository):
 			self._collectSingleFilePackageNames,
 		)
 
+	def getAvailableVersions(self, packageName, distribution, component, architecture):
+		def collectSingleFilePackageVersion(availableVersions, package):
+			if self._packageFileExists(package):
+				availableVersions.append(package["Version"])
+
+		versions = self._getAvailablePackageNames(
+			self._packageLists,
+			(distribution, component, architecture),
+			collectSingleFilePackageVersion,
+		)
+		versions.sort()
+		return tuple(versions)
+
 	def _collectSingleFilePackageNames(self, availableNames, package):
-		filename = os.path.join(self._baseDir, package["Filename"])
-		if os.path.exists(filename):
+		if self._packageFileExists(package):
 			availableNames.append(package["Package"])
-		else:
-			print "*** %s not found" % filename
 
 	def getAvailableSourcePackageNames(self, distribution, component):
 		def collector(availableNames, package):
@@ -181,13 +191,20 @@ class AutomaticRepository(AbstractRepository):
 			collector,
 		)
 
+	def _packageFileExists(self, package):
+		filename = os.path.join(self._baseDir, package["Filename"])
+		exists = os.path.exists(filename)
+		if not exists:
+			print "*** %s not found" % filename
+		return exists
+
 	def _getAvailablePackageNames(self, packageLists, key, collector):
 		packageList = packageLists.get(key)
 		if packageList is None:
 			return []
 
 		availableNames = []
-		for package in packageList._packages.itervalues():
+		for package in packageList.iterfields():
 			collector(availableNames, package)
 		return availableNames
 
@@ -290,21 +307,30 @@ class TrivialRepository(AbstractRepository):
 
 class _PackageList:
 	def __init__(self):
-		self._packages = {}
+		self._packages = []
+		self._packagesByName = {}
 
 	def addPackage(self, name, **kw):
+		nameParts = name.split("_")
+		if len(nameParts) > 1:
+			name = nameParts[0]
+			defaultVersion = nameParts[1]
+		else:
+			defaultVersion ="1.0"
+
 		fields = {
-			"Version" : "1.0",
+			"Version" : defaultVersion,
 			"Priority" : "optional",
 			"Architecture" : "any",
 			"Section" : "python",
 		}
 		fields.update(kw)
-		self._packages[name] = fields
+		self._packages.append((name, fields))
+		self._packagesByName.setdefault(name, {})[fields["Version"]] = fields
 
 	def calculateIndexFile(self, defaultArchitecture, filenameGenerator):
 		lines = []
-		for packageName, fields in self._packages.iteritems():
+		for packageName, fields in self._packages:
 			architecture = fields["Architecture"]
 			if architecture != "all":
 				architecture = defaultArchitecture
@@ -323,9 +349,18 @@ class _PackageList:
 	def getExtension(self):
 		return "deb"
 
-	def getPackage(self, packageName):
-		return self._packages[packageName]
+	def getPackage(self, packageName, version=None):
+		packages = self._packagesByName[packageName]
+		if len(packages) == 1 and version is None:
+			return packages.values()[0]
+		if version is None:
+			raise RuntimeError("Multiple versions exist for '%s' but no version spectified" % packageName)
 
+		return packages[version]
+
+	def iterfields(self):
+		for name, fields in self._packages:
+			yield fields
 
 class _InstallerPackageList(_PackageList):
 	def getExtension(self):
@@ -360,7 +395,7 @@ class _SourcePackageList:
 			contents = "simulated contents of %s" % filename
 			files[os.path.join(directory, filename)] = contents
 			return " %s %s %s" % (
-				md5.md5(contents).hexdigest(),
+				hashlib.md5(contents).hexdigest(),
 				len(contents),
 				filename,
 			)
