@@ -145,6 +145,31 @@ server = file://%s
 		self.checkPackages(["package1", "package3"], mirroredRepository, distribution="etch", component="main", architecture="arm")
 
 
+	def test01f(self):
+		""" Mirror a pooled repository : keep latest version per architecture """
+		sourceRepository = PooledRepository()
+
+		self.addPackages(sourceRepository, ["package1_1.0", "package1_1.1"], distribution="etch", component="main", architecture="i386")
+		self.addPackages(sourceRepository, ["package1_1.2"], distribution="etch", component="main", architecture="arm")
+		sourceDir = self.writeRepository(sourceRepository)
+
+		globalConfiguration, mirrorDir = self.createGlobalConfiguration(
+			architectures = "i386 arm",
+		)
+		configuration = self.loadConfiguration(globalConfiguration + """
+[myRepo]
+server = file://%s
+"""% sourceDir)
+
+		self.doAll(configuration)
+
+		mirroredRepository = self.readMirror(PooledRepository, mirrorDir,multi=True)
+		#self.failUnlessEqual(("1.0", "1.1"), sourceRepository.getAvailableVersions("package1",  distribution="etch", component="main", architecture="i386"))
+		self.failUnlessEqual(("1.1", ), mirroredRepository.getAvailableVersions("package1",  distribution="etch", component="main", architecture="i386"))
+
+		self.failUnlessEqual(("1.2", ), mirroredRepository.getAvailableVersions("package1",  distribution="etch", component="main", architecture="arm"))
+
+
 	def test02a(self):
 		""" Mirror a pooled repository - filters """
 		sourceRepository = PooledRepository()
