@@ -4,7 +4,7 @@
 #
 #  Debian Partial Mirror is a tool to make complete and partial Debian mirrors.
 #  See http://projetos.ossystems.com.br/debpartial-mirror/ for more information.
-#    
+#
 # ====================================================================
 # Copyright (c) 2002-2005 O.S. Systems.  All rights reserved.
 #
@@ -18,15 +18,15 @@ import unittest
 
 import TestConfig
 import TestDownload
+import TestEndToEnd
 
 def suite():
 	suite = unittest.TestSuite()
-
 	suite.addTest(TestConfig.suite())
 	suite.addTest(TestDownload.suite())
-
-
+	suite.addTest(TestEndToEnd.suite())
 	return suite
-	
+
+
 if __name__ == '__main__':
 	unittest.main(defaultTest='suite')
